@@ -625,7 +625,9 @@ DESCRIPTIONFileDeps <- function(desc_path, which = c("Depends", "Imports", "Link
     suppressWarnings(vers <- gsub(grepVersion, "", grep(grepVersion, desc_path, value = TRUE)))
     paste(pkg, vers, sep = "_", paste0(which, "_", keepVersionNumber, collapse = "_"))
   }
-  if (!exists(objName, envir = .pkgEnv[["pkgDep"]][["DESCRIPTIONFile"]]) || isTRUE(purge)) {
+  if (isTRUE(length(objName) > 1) || 
+      isTRUE(any(!exists(objName, envir = .pkgEnv[["pkgDep"]][["DESCRIPTIONFile"]]))) || 
+      isTRUE(purge)) {
     lines <- if (length(desc_path) == 1)
       try(readLines(desc_path))
     else
